@@ -5,7 +5,7 @@ import polars as pl
 import requests
 
 from cameo_claw.file import mkdir
-from cameo_claw.net import requests_get, url_to_filename
+from cameo_claw.net import requests_get, url_to_filename, requests_get_ram_cache
 
 import warnings
 import pandas as pd
@@ -22,7 +22,7 @@ def bytesio_to_gzip(df, url, target_directory):
 
 def requests_get_write(target_directory, url, f_write):
     try:
-        return requests_get(f_write, url, target_directory)
+        return requests_get_ram_cache(f_write, url, target_directory)
     except Exception as e:
         print(f'cameo_claw.py,requests_get_write,Exception:{e, url}')
 
