@@ -3,7 +3,7 @@ import sys
 
 import requests
 
-from cameo_claw import it_distinct, it_streaming_pd, it_group, it_filter, server
+from cameo_claw import it_distinct, it_streaming_pd, it_group, it_filter, server, it_filter_group
 import time
 from cameo_claw.log import log
 
@@ -261,18 +261,31 @@ def test_client():
         f.write(r.content)
 
 
+def test_it_filter_group():
+    target_directory = './data/topic_filter_group/'
+    int_total = len(get_lst_url_taipei_100())
+    lst_distinct_column = ['deviceId', 'localTime', 'sensorId']
+    lst_column_match = [['sensorId', 'pm2_5'], ['sensorId', 'voc']]
+    sort_column = 'localTime'
+    lst_group_by_column = ['deviceId']
+    for int_progress, done_url in it_filter_group(
+            get_lst_url_taipei_100(), target_directory, lst_distinct_column,
+            lst_column_match, sort_column, lst_group_by_column):
+        pass
+
+
 if __name__ == '__main__':
-    print('sh/go.sh server')
-    print('sh/go.sh client')
-    print('sh/go.sh filter')
-    if sys.argv[1] == 'server':
-        test_server()
-    if sys.argv[1] == 'client':
-        test_client()
-    if sys.argv[1] == 'filter':
-        t = time.time()
-        test_it_filter()
-        log(f'test_it_filter:{time.time() - t}')
+    # print('sh/go.sh server')
+    # print('sh/go.sh client')
+    # print('sh/go.sh filter')
+    # if sys.argv[1] == 'server':
+    #     test_server()
+    # if sys.argv[1] == 'client':
+    #     test_client()
+    # if sys.argv[1] == 'filter':
+    #     t = time.time()
+    #     test_it_filter()
+    #     log(f'test_it_filter:{time.time() - t}')
 
     # t = time.time()
     # test_it_download()
@@ -286,4 +299,8 @@ if __name__ == '__main__':
     # test_it_group()
     # log(f'test_it_group:{time.time() - t}')
 
+    t = time.time()
+    test_it_filter_group()
+    log(f'test_it_group:{time.time() - t}')
+
 # sh/go.sh
